@@ -47,7 +47,7 @@ def _key_by_table(db, table, cursor):
         p.execute()
     #else:
     #    print mc_keyer.decode(mckey)
-    return mckey.replace("\\","\\\\")
+    return mckey.replace("\\","\\\\").replace("%","%%")
 
 class _Model(type):
     def __new__(cls, name, bases, attrs):
